mangadap.spectra package
========================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.spectra.manga
   mangadap.spectra.rowstackedspectra

Module contents
---------------

.. automodule:: mangadap.spectra
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
